@@ -3,16 +3,20 @@ from fixieai.agents.api import AgentResponse
 from fixieai.agents.api import Embed
 from fixieai.agents.api import Message
 from fixieai.agents.code_shot import CodeShotAgent
+from fixieai.agents.corpora import DocumentCorpus
+from fixieai.agents.corpora import DocumentLoader
 from fixieai.agents.oauth import OAuthHandler
 from fixieai.agents.oauth import OAuthParams
 from fixieai.agents.user_storage import UserStorage
 
 __all__ = [
-    "Message",
-    "Embed",
     "AgentQuery",
     "AgentResponse",
     "CodeShotAgent",
+    "DocumentCorpus",
+    "DocumentLoader",
+    "Embed",
+    "Message",
     "OAuthHandler",
     "OAuthParams",
     "UserStorage",
