@@ -312,7 +312,8 @@ def _configure_venv(
 
     venv_path = os.path.join(agent_dir, ".venv")
     console.print(f"Configuring virtual environment in {venv_path}")
-    venv.create(venv_path, with_pip=True)
+    if not os.path.exists(venv_path):
+        venv.create(venv_path, with_pip=True)
     python_exe = os.path.join(venv_path, "bin", "python")
     requirements_txt_path = os.path.join(agent_dir, REQUIREMENTS_TXT)
     if not os.path.exists(requirements_txt_path):
@@ -393,7 +394,7 @@ def serve(ctx, path, host, port, use_tunnel, reload, use_venv):
     config = agent_config.load_config(path)
 
     with contextlib.ExitStack() as stack:
-        agent_dir = os.path.dirname(path)
+        agent_dir = os.path.dirname(path) or "."
 
         # Configure the virtual enviroment
         if use_venv:
@@ -498,7 +499,7 @@ def deploy(ctx, path, metadata_only, validate):
     console = rich_console.Console(soft_wrap=True)
     config = agent_config.load_config(path)
 
-    agent_dir = os.path.dirname(path)
+    agent_dir = os.path.dirname(path) or "."
     if validate:
         # Validate that the agent loads in a virtual environment before deploying.
         python_exe, agent_env = _configure_venv(console, agent_dir)
@@ -512,11 +513,10 @@ def deploy(ctx, path, metadata_only, validate):
         # Deploy the agent to fixie with some bootstrapping code.
         with tempfile.TemporaryFile() as tarball_file:
             with tarfile.open(fileobj=tarball_file, mode="w:gz") as tarball:
-                deploy_root = os.path.dirname(path)
                 tarball.add(
-                    deploy_root,
+                    agent_dir,
                     arcname="agent",
-                    filter=functools.partial(_tarinfo_filter, console, deploy_root),
+                    filter=functools.partial(_tarinfo_filter, console, agent_dir),
                 )
 
                 # Add the bootstrapping code
